==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d8/d50/gamelog_8cpp.js <==
var gamelog_8cpp =
[
    [ "GRFPresence", "da/dd8/structGRFPresence.html", "da/dd8/structGRFPresence" ],
    [ "GRFList", "de/da1/structGRFList.html", "de/da1/structGRFList" ],
    [ "GrfIDMapping", "d8/d50/gamelog_8cpp.html#a037fec9488b4b7597450613a13a84edc", null ],
    [ "assert_compile", "d8/d50/gamelog_8cpp.html#a9f79dda7ce4e0dd7853bd8e44d2d5852", null ],
    [ "GamelogChange", "d8/d50/gamelog_8cpp.html#a516730ecdb1863a87c7243802110d3f9", null ],
    [ "GamelogEmergency", "d8/d50/gamelog_8cpp.html#adffab83111f6eeba34984f7aca106927", null ],
    [ "GamelogFree", "d8/d50/gamelog_8cpp.html#ae65ed6185a291c7dabae66a20e814890", null ],
    [ "GamelogGRFAdd", "d8/d50/gamelog_8cpp.html#abac5c23c0b032e653a39956ecbd0b956", null ],
    [ "GamelogGRFAddList", "d8/d50/gamelog_8cpp.html#a8c08e01698328f13e406393ca64d0ea4", null ],
    [ "GamelogGRFBug", "d8/d50/gamelog_8cpp.html#aeeb41da913c8fa24a4889482d3acb820", null ],
    [ "GamelogGRFBugReverse", "d8/d50/gamelog_8cpp.html#a7cd9daf69ad8adf725a3223db1ba2ef5", null ],
    [ "GamelogGRFCompatible", "d8/d50/gamelog_8cpp.html#a4fae58c6f303dfbf263a81aec3727ba9", null ],
    [ "GamelogGRFMove", "d8/d50/gamelog_8cpp.html#a1d324c71a891f483f40088625c995405", null ],
    [ "GamelogGRFParameters", "d8/d50/gamelog_8cpp.html#a551e828f8ab3811d9cf24708bdf5cdf0", null ],
    [ "GamelogGRFRemove", "d8/d50/gamelog_8cpp.html#ae13abd415e66157b95ffe293742e12c2", null ],
    [ "GamelogGRFUpdate", "d8/d50/gamelog_8cpp.html#a0cf54f21375ab6b9273c0af86d789587", null ],
    [ "GamelogInfo", "d8/d50/gamelog_8cpp.html#a989b3cb11a30e0fd7e9a5f451b0675da", null ],
    [ "GamelogMode", "d8/d50/gamelog_8cpp.html#ab166f6e82c72e8c1eac4ea1c4a28b205", null ],
    [ "GamelogOldver", "d8/d50/gamelog_8cpp.html#ada14bdfb290628cde86d14c389faa1dd", null ],
    [ "GamelogPrint", "d8/d50/gamelog_8cpp.html#a4a9597cd8d1362dc44fd396b2bd7c042", null ],
    [ "GamelogPrintConsole", "d8/d50/gamelog_8cpp.html#adda4985b46536f2fe5a443c367c38ec8", null ],
    [ "GamelogPrintConsoleProc", "d8/d50/gamelog_8cpp.html#a068c4fb8617afce29caec139e896cb85", null ],
    [ "GamelogPrintDebug", "d8/d50/gamelog_8cpp.html#a2147a0be92d0e4b2497f9ae9f34d98ee", null ],
    [ "GamelogPrintDebugProc", "d8/d50/gamelog_8cpp.html#a9fe0f450689b15299e6abc30257128c2", null ],
    [ "GamelogReset", "d8/d50/gamelog_8cpp.html#a13eb79f8b7081fa2c2ef51f32abcf031", null ],
    [ "GamelogRevision", "d8/d50/gamelog_8cpp.html#ad58525ff4949486c0d58daac2d77e23b", null ],
    [ "GamelogSetting", "d8/d50/gamelog_8cpp.html#af5530b7f5b59bc7e51819e0d68e00929", null ],
    [ "GamelogStartAction", "d8/d50/gamelog_8cpp.html#acc27ac2320bbb229f024ed9874379b00", null ],
    [ "GamelogStopAction", "d8/d50/gamelog_8cpp.html#a9f30c5f55958468d66f3aafeeeffc08d", null ],
    [ "GamelogTestEmergency", "d8/d50/gamelog_8cpp.html#ad4fb58850fd3cf3f6c85d245acc618e4", null ],
    [ "GamelogTestMode", "d8/d50/gamelog_8cpp.html#ab700fe64a469e014397ca153ca23c159", null ],
    [ "GamelogTestRevision", "d8/d50/gamelog_8cpp.html#ae8bb0beb497149301fafd874baf9fbba", null ],
    [ "GenerateGRFList", "d8/d50/gamelog_8cpp.html#af6852da1fb5f294bf7545d9135bee1b3", null ],
    [ "GetGamelogRevisionString", "d8/d50/gamelog_8cpp.html#aa27f7cb7b7cfe8d47671141a1ccf85f2", null ],
    [ "IsLoggableGrfConfig", "d8/d50/gamelog_8cpp.html#ac3a583e67a763c914a3699f0ec9379ec", null ],
    [ "PrintGrfInfo", "d8/d50/gamelog_8cpp.html#ab990eafb49912c49e2c283060e05198e", null ],
    [ "_current_action", "d8/d50/gamelog_8cpp.html#ac1e8206a311801d0e99f14cd6e3de002", null ],
    [ "_gamelog_action", "d8/d50/gamelog_8cpp.html#a06a2c5145732449126b77e8ddfe76f7d", null ],
    [ "_gamelog_action_type", "d8/d50/gamelog_8cpp.html#a997ed020b62a73cfd7f9c891f97fe12b", null ],
    [ "_gamelog_actions", "d8/d50/gamelog_8cpp.html#a07c94c29a407986e8a750d62d73c23a4", null ],
    [ "_gamelog_print_level", "d8/d50/gamelog_8cpp.html#aefe75d285ddd9cdb3b509847ea2c8706", null ],
    [ "_savegame_type", "d8/d50/gamelog_8cpp.html#ab0504e56d591d788e2c5243fd247c0ec", null ],
    [ "_sl_minor_version", "d8/d50/gamelog_8cpp.html#a8a25d0abbb40341caa0b2c65fa2c936e", null ],
    [ "_sl_version", "d8/d50/gamelog_8cpp.html#a222b94f5c501589c7ae9cb39ef173d5c", null ],
    [ "_ttdp_version", "d8/d50/gamelog_8cpp.html#a8d20b8886588be7c56ecbc1d055d391d", null ],
    [ "la_text", "d8/d50/gamelog_8cpp.html#a6177424b30b71c3917bfeb961cc8ea5f", null ],
    [ "SAVEGAME_VERSION", "d8/d50/gamelog_8cpp.html#acbffd90ba63d5267c55da9ae621e259f", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d8/d50/gamelog_8cpp.js <==
var gamelog_8cpp =
[
    [ "GRFPresence", "da/dd8/structGRFPresence.html", "da/dd8/structGRFPresence" ],
    [ "GRFList", "de/da1/structGRFList.html", "de/da1/structGRFList" ],
    [ "GrfIDMapping", "d8/d50/gamelog_8cpp.html#a037fec9488b4b7597450613a13a84edc", null ],
    [ "GamelogChange", "d8/d50/gamelog_8cpp.html#a516730ecdb1863a87c7243802110d3f9", null ],
    [ "GamelogEmergency", "d8/d50/gamelog_8cpp.html#adffab83111f6eeba34984f7aca106927", null ],
    [ "GamelogFree", "d8/d50/gamelog_8cpp.html#ae65ed6185a291c7dabae66a20e814890", null ],
    [ "GamelogGRFAdd", "d8/d50/gamelog_8cpp.html#abac5c23c0b032e653a39956ecbd0b956", null ],
    [ "GamelogGRFAddList", "d8/d50/gamelog_8cpp.html#a8c08e01698328f13e406393ca64d0ea4", null ],
    [ "GamelogGRFBug", "d8/d50/gamelog_8cpp.html#aeeb41da913c8fa24a4889482d3acb820", null ],
    [ "GamelogGRFBugReverse", "d8/d50/gamelog_8cpp.html#a7cd9daf69ad8adf725a3223db1ba2ef5", null ],
    [ "GamelogGRFCompatible", "d8/d50/gamelog_8cpp.html#a4fae58c6f303dfbf263a81aec3727ba9", null ],
    [ "GamelogGRFMove", "d8/d50/gamelog_8cpp.html#a1d324c71a891f483f40088625c995405", null ],
    [ "GamelogGRFParameters", "d8/d50/gamelog_8cpp.html#a551e828f8ab3811d9cf24708bdf5cdf0", null ],
    [ "GamelogGRFRemove", "d8/d50/gamelog_8cpp.html#ae13abd415e66157b95ffe293742e12c2", null ],
    [ "GamelogGRFUpdate", "d8/d50/gamelog_8cpp.html#a0cf54f21375ab6b9273c0af86d789587", null ],
    [ "GamelogInfo", "d8/d50/gamelog_8cpp.html#a989b3cb11a30e0fd7e9a5f451b0675da", null ],
    [ "GamelogMode", "d8/d50/gamelog_8cpp.html#ab166f6e82c72e8c1eac4ea1c4a28b205", null ],
    [ "GamelogOldver", "d8/d50/gamelog_8cpp.html#ada14bdfb290628cde86d14c389faa1dd", null ],
    [ "GamelogPrint", "d8/d50/gamelog_8cpp.html#a4a9597cd8d1362dc44fd396b2bd7c042", null ],
    [ "GamelogPrintConsole", "d8/d50/gamelog_8cpp.html#adda4985b46536f2fe5a443c367c38ec8", null ],
    [ "GamelogPrintConsoleProc", "d8/d50/gamelog_8cpp.html#a068c4fb8617afce29caec139e896cb85", null ],
    [ "GamelogPrintDebug", "d8/d50/gamelog_8cpp.html#a2147a0be92d0e4b2497f9ae9f34d98ee", null ],
    [ "GamelogPrintDebugProc", "d8/d50/gamelog_8cpp.html#a9fe0f450689b15299e6abc30257128c2", null ],
    [ "GamelogReset", "d8/d50/gamelog_8cpp.html#a13eb79f8b7081fa2c2ef51f32abcf031", null ],
    [ "GamelogRevision", "d8/d50/gamelog_8cpp.html#ad58525ff4949486c0d58daac2d77e23b", null ],
    [ "GamelogSetting", "d8/d50/gamelog_8cpp.html#af5530b7f5b59bc7e51819e0d68e00929", null ],
    [ "GamelogStartAction", "d8/d50/gamelog_8cpp.html#acc27ac2320bbb229f024ed9874379b00", null ],
    [ "GamelogStopAction", "d8/d50/gamelog_8cpp.html#a9f30c5f55958468d66f3aafeeeffc08d", null ],
    [ "GamelogStopAnyAction", "d8/d50/gamelog_8cpp.html#a3a33bd39904b89af05c4cc4d38fea172", null ],
    [ "GamelogTestEmergency", "d8/d50/gamelog_8cpp.html#ad4fb58850fd3cf3f6c85d245acc618e4", null ],
    [ "GamelogTestMode", "d8/d50/gamelog_8cpp.html#ab700fe64a469e014397ca153ca23c159", null ],
    [ "GamelogTestRevision", "d8/d50/gamelog_8cpp.html#ae8bb0beb497149301fafd874baf9fbba", null ],
    [ "GenerateGRFList", "d8/d50/gamelog_8cpp.html#af6852da1fb5f294bf7545d9135bee1b3", null ],
    [ "GetGamelogRevisionString", "d8/d50/gamelog_8cpp.html#aa27f7cb7b7cfe8d47671141a1ccf85f2", null ],
    [ "IsLoggableGrfConfig", "d8/d50/gamelog_8cpp.html#ac3a583e67a763c914a3699f0ec9379ec", null ],
    [ "PrintGrfInfo", "d8/d50/gamelog_8cpp.html#ab990eafb49912c49e2c283060e05198e", null ],
    [ "_current_action", "d8/d50/gamelog_8cpp.html#ac1e8206a311801d0e99f14cd6e3de002", null ],
    [ "_gamelog_action", "d8/d50/gamelog_8cpp.html#a06a2c5145732449126b77e8ddfe76f7d", null ],
    [ "_gamelog_action_type", "d8/d50/gamelog_8cpp.html#a997ed020b62a73cfd7f9c891f97fe12b", null ],
    [ "_gamelog_actions", "d8/d50/gamelog_8cpp.html#a07c94c29a407986e8a750d62d73c23a4", null ],
    [ "_gamelog_print_level", "d8/d50/gamelog_8cpp.html#aefe75d285ddd9cdb3b509847ea2c8706", null ],
    [ "_savegame_type", "d8/d50/gamelog_8cpp.html#ab0504e56d591d788e2c5243fd247c0ec", null ],
    [ "_sl_minor_version", "d8/d50/gamelog_8cpp.html#a8a25d0abbb40341caa0b2c65fa2c936e", null ],
    [ "_sl_version", "d8/d50/gamelog_8cpp.html#a222b94f5c501589c7ae9cb39ef173d5c", null ],
    [ "_ttdp_version", "d8/d50/gamelog_8cpp.html#a8d20b8886588be7c56ecbc1d055d391d", null ],
    [ "la_text", "d8/d50/gamelog_8cpp.html#a6177424b30b71c3917bfeb961cc8ea5f", null ],
    [ "SAVEGAME_VERSION", "d8/d50/gamelog_8cpp.html#acbffd90ba63d5267c55da9ae621e259f", null ]
];
